@@ -1,6 +1,6 @@
 /* ink.c
  *
- * (c) 2010 Markus Heinz
+ * (c) 2010, 2014, 2015 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -14,8 +14,11 @@
 #include <unistd.h>
 #include <string.h>
 
+void usage(void);
+void print_version_information(void);
+
 void usage(void) {
-  printf("ink -p \"usb\"|\"parport\" [-n <portnumber>] [-t <threshold>] | -d <device_file>\n");
+  printf("ink -p \"usb\"|\"parport\" [-n <portnumber>] [-t <threshold>]\n");
   printf("ink -p \"bjnp\" | -b \"bjnp://<printer.my.domain>\" | -v\n\n");
 
   printf("'ink -p parport' Query first parallel port printer\n");
@@ -23,7 +26,6 @@ void usage(void) {
   printf("'ink -p usb' Query first usb port printer\n");
   printf("'ink -p usb -n 1' Query second usb port printer\n");
   printf("'ink -p bjnp' Query first bjnp network printer\n");
-  printf("'ink -d /dev/usblp0' Query usb printer on device /dev/usblp0\n");
   printf("'ink -b bjnp://printer.my.domain' Query bjnp network printer on printer.my.domain\n");
   printf("'ink -b bjnp://111.222.111.222' Query bjnp network printer on ip-address 111.222.111.222\n");
   printf("'ink -p usb -t 20' Only print ink levels less than or equal to 20%%\n");
@@ -33,11 +35,9 @@ void usage(void) {
 void print_version_information(void) {
   char *libinklevel_version_string;
 
-  printf(PACKAGE_STRING);
-  printf("\n");
+  printf("%s\n", PACKAGE_STRING);
   libinklevel_version_string = get_version_string();
-  printf(libinklevel_version_string);
-  printf("\n");
+  printf("%s\n", libinklevel_version_string);
 }
 
 int main(int argc, char *argv[]) {
@@ -74,7 +74,7 @@ int main(int argc, char *argv[]) {
     "Matte Black:",
     "Gloss Optimizer:",
     "Unknown:",
-    "Black, Cyan, Magenta:",
+    "Light Cyan, Light Magenta, Photoblack:",
     "2x Grey and Black:",
     "Black, Cyan, Magenta, Yellow:",
     "Photocyan and Photomagenta:",
@@ -88,7 +88,7 @@ int main(int argc, char *argv[]) {
   };
 
   strcat(headerline, PACKAGE_STRING);
-  strcat(headerline, " (c) 2010 Markus Heinz\n\n");
+  strcat(headerline, " (c) 2015 Markus Heinz\n\n");
 
   if (argc == 1) {
     usage();
@@ -165,61 +165,100 @@ int main(int argc, char *argv[]) {
 
   if (result != OK) {
     switch (result) {
+
     case ERROR:
       printf("An unknown error occured.\n");
       break;
+
     case DEV_PARPORT_INACCESSIBLE:
       printf("Could not access '/dev/parport%d'.\n", portnumber);
       break;
+
     case DEV_LP_INACCESSIBLE:
+
+#if (HOST_OS == LINUX)
+
       printf("Could not access '/dev/lp%d'.\n", portnumber);
+
+#elif (HOST_OS == SOLARIS)
+
+      printf("Could not access '/dev/ecpp%d'.\n", portnumber);
+     
+#elif (HOST_OS == FREEBSD)
+
+      printf("Could not access '/dev/lpt%d'.\n", portnumber);
+
+#endif
+
       break;
+
     case COULD_NOT_GET_DEVICE_ID:
       printf("Could not get device id.\n");
       break;
+
     case DEV_USB_LP_INACCESSIBLE:
+
+#if (HOST_OS != SOLARIS)
+
       printf("Could not access '/dev/usb/lp%d' or '/dev/usblp%d'.\n", 
              portnumber, portnumber);
+
+#else
+
+      printf("Could not access '/dev/usb/printer%d'.\n", portnumber);
+
+#endif
+
       break;
+
     case UNKNOWN_PORT_SPECIFIED:
       printf("Unknown port specified.\n");
       break;
+
     case NO_PRINTER_FOUND:
       printf("No printer found.\n");
       break;
+
     case NO_DEVICE_CLASS_FOUND:
       printf("No device class found.\n");
       break;
+
     case NO_CMD_TAG_FOUND:
       printf("No cmd tag found.\n");
       break;
+
     case PRINTER_NOT_SUPPORTED:
       printf("Printer not supported.\n");
       break;
+
     case NO_INK_LEVEL_FOUND:
       printf("No ink level found.\n");
       break;
+
     case COULD_NOT_WRITE_TO_PRINTER:
       printf("Could not write to printer.\n");
       break;
+
     case COULD_NOT_READ_FROM_PRINTER:
       printf("Could not read from printer.\n");
       break;
+
     case COULD_NOT_PARSE_RESPONSE_FROM_PRINTER:
       printf("Could not parse response from printer.\n");
       break;
+
     case COULD_NOT_GET_CREDIT:
       printf("Could not get credit.\n");
       break;
-    case DEV_CUSTOM_USB_INACCESSIBLE:
-      printf("Could not access custom usb device '%s'.\n", devicefile);
-      break;
+
     case BJNP_URI_INVALID:
       printf("Printer URI is invalid: '%s'.\n", devicefile);
       break;
+
     case BJNP_INVALID_HOSTNAME:
       printf("Could not open hostname: '%s'.\n", devicefile);
       break;
+
    }
     printf("Could not get ink level.\n");
     free(level);
@@ -235,13 +274,13 @@ int main(int argc, char *argv[]) {
     for(i = 0; i < MAX_CARTRIDGE_TYPES; i++) {
       if (threshold == -1 || level->levels[i][INDEX_LEVEL] <= threshold) {
 	if (headerNeeded) {
-	  printf(headerline);
+	  printf("%s", headerline);
 	  printf("%s\n\n", level->model);
 	  headerNeeded = 0;
 	}
 	if(level->levels[i][INDEX_TYPE] != CARTRIDGE_NOT_PRESENT) {
 
-	  printf("%-29s %3d%%\n", strCartridges[level->levels[i][INDEX_TYPE]],
+	  printf("%-38s %3d%%\n", strCartridges[level->levels[i][INDEX_TYPE]],
 		 level->levels[i][INDEX_LEVEL]);
 	} else {
 	  break;
